@@ -22,12 +22,11 @@ from bcolz.tests import common
 from bcolz.tests.common import (
     MayBeDiskTest, TestCase, unittest, skipUnless, SkipTest)
 import bcolz
-from bcolz.py2help import xrange, PY2
+from bcolz.py2help import xrange, PY2, _inttypes
 from bcolz.carray_ext import chunk
 from bcolz import carray
 import pickle
 
-
 import ctypes
 
 is_64bit = (struct.calcsize("P") == 8)
@@ -2243,6 +2242,16 @@ class ContextManagerTest(MayBeDiskTest, TestCase):
         expected = np.array([1])
         assert_array_equal(expected, received)
 
+    def test_with_read_only(self):
+        x = bcolz.arange(5, rootdir=self.rootdir, mode="w")
+        x.flush()
+        sx = sum(i for i in x)
+
+        with bcolz.open(self.rootdir, mode='r') as xreadonly:
+            sxreadonly = sum(i for i in xreadonly)
+        self.assertEquals(sx, sxreadonly)
+
+
 class nleftoversTest(TestCase):
 
     def test_empty(self):
@@ -2337,6 +2346,44 @@ class LeftoverDiskTest(LeftoverTest, TestCase):
             out = ctypes.c_int32.from_address(b.leftover_ptr + (i * typesize))
             self.assertEqual((n_chunks * chunklen) + i, out.value)
 
+    def test_repr_of_empty_object_array(self):
+        assert 'ratio: nan' in repr(carray(np.array([], dtype=object)))
+
+
+class MagicNumbers(MayBeDiskTest):
+
+    def test_type_i4(self):
+        N = 2**16
+        ca = carray([i for i in range(N)], dtype='i4', rootdir=self.rootdir)
+
+        for i in range(len(ca)):
+            v = ca[i]
+            self.assertTrue(isinstance(v, _inttypes))
+
+    def test_type_i8(self):
+        N = 2**15
+        ca = carray([i for i in range(N)], dtype='i8', rootdir=self.rootdir)
+
+        for i in range(len(ca)):
+            v = ca[i]
+            self.assertTrue(isinstance(v, _inttypes))
+
+    def test_type_f8(self):
+        N = 2**15
+        ca = carray([i for i in range(N)], dtype='f8', rootdir=self.rootdir)
+
+        for i in range(len(ca)):
+            v = ca[i]
+            self.assertTrue(isinstance(v, float))
+
+
+class MagicNumbersMemoryTest(MagicNumbers, TestCase):
+    disk = False
+
+
+class MagicNumbersDiskTest(MagicNumbers, TestCase):
+    disk = True
+
 
 if __name__ == '__main__':
     unittest.main(verbosity=2)
